# python-lvis

[![pypi Status](https://badge.fury.io/py/python-lvis.png)](https://badge.fury.io/py/python-lvis)
[![Build Status](https://travis-ci.org/thorgate/python-lvis.svg?branch=master)](https://travis-ci.org/thorgate/python-lvis)

Python bindings for https://www.veoseleht.ee API (aka ELVIS), requires ELVIS proxy that translates requests from 
rest to SOAP (you can use https://gitlab.com/thorgate-public/lvisproxy/ proxy for this)

